summaryrefslogtreecommitdiffstats
path: root/kugar/part/kugar_factory.h
diff options
context:
space:
mode:
Diffstat (limited to 'kugar/part/kugar_factory.h')
-rw-r--r--kugar/part/kugar_factory.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/kugar/part/kugar_factory.h b/kugar/part/kugar_factory.h
index c809870b..3ee962f8 100644
--- a/kugar/part/kugar_factory.h
+++ b/kugar/part/kugar_factory.h
@@ -10,7 +10,7 @@
#include <KoFactory.h>
#include <kaboutdata.h>
-class KInstance;
+class TDEInstance;
class KugarFactory : public KoFactory
@@ -25,13 +25,13 @@ public:
TQObject *parent = 0, const char *name = 0, const char *classname = "KoDocument",
const TQStringList &args = TQStringList() );
- static KInstance* global();
+ static TDEInstance* global();
- // _Creates_ a KAboutData but doesn't keep ownership
- static KAboutData* aboutData();
+ // _Creates_ a TDEAboutData but doesn't keep ownership
+ static TDEAboutData* aboutData();
private:
- static KInstance* s_instance;
- static KAboutData* s_aboutdata;
+ static TDEInstance* s_instance;
+ static TDEAboutData* s_aboutdata;
};
#endif